@@ -163,6 +163,5 @@ class DBEvent:
     def _raise_values(self, fields):
         values = {}
         for key in fields:
-            value_type = next(iter(fields[key]))
-            values[key] = self._raise_value(fields[value_type])
+            values[key] = self._raise_value(fields[key])
         return values
