@@ -39,3 +39,11 @@ def valid_chid(chid):
         parts = chid.split("/")
         return len(parts) == 2 and valid_id(parts[0]) and valid_chid_suffix(parts[1])
     return False
+
+
+def valid_apply_ref(ref):
+    return (
+        isinstance(ref, str)
+        and ref.startswith("tf/apply")
+        and valid_id(ref.split("/")[2])
+    )
